#include "cfl_box.h"
#include "cfl_lock.h"

#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Image.H>

WIDGET_CLASS(Fl_Box)

WIDGET_DEFINE(Fl_Box)
